==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/flows/v1/SequenceSpecBuilder.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SequenceSpecBuilder extends SequenceSpecFluentImpl<SequenceSpecBuilder> implements VisitableBuilder<SequenceSpec,SequenceSpecBuilder> {

    SequenceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SequenceSpecBuilder() { 
        this(true);
    }


    public SequenceSpecBuilder(Boolean validationEnabled) { 
        this(new SequenceSpec(), validationEnabled);
    }


    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SequenceSpec(), validationEnabled);
    }


    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent,SequenceSpec instance) { 
        this(fluent, instance, true);
    }


    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent,SequenceSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withChannelTemplate(instance.getChannelTemplate()); 
        fluent.withReply(instance.getReply()); 
        fluent.withSteps(instance.getSteps()); 
        this.validationEnabled = validationEnabled; 
    }


    public SequenceSpecBuilder(SequenceSpec instance) { 
        this(instance,true);
    }


    public SequenceSpecBuilder(SequenceSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withChannelTemplate(instance.getChannelTemplate()); 
        this.withReply(instance.getReply()); 
        this.withSteps(instance.getSteps()); 
        this.validationEnabled = validationEnabled; 
    }


    public SequenceSpec build() {
        SequenceSpec buildable = new SequenceSpec(fluent.getChannelTemplate(),fluent.getReply(),fluent.getSteps());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SequenceSpecBuilder that = (SequenceSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/flows/v1/SequenceSpecBuilder.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SequenceSpecBuilder extends SequenceSpecFluentImpl<SequenceSpecBuilder> implements VisitableBuilder<SequenceSpec,SequenceSpecBuilder> {

    SequenceSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SequenceSpecBuilder() {
        this(true);
    }

    public SequenceSpecBuilder(Boolean validationEnabled) {
        this(new SequenceSpec(), validationEnabled);
    }

    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SequenceSpec(), validationEnabled);
    }

    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent,SequenceSpec instance) {
        this(fluent, instance, true);
    }

    public SequenceSpecBuilder(SequenceSpecFluent<?> fluent,SequenceSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withChannelTemplate(instance.getChannelTemplate()); 
        fluent.withReply(instance.getReply()); 
        fluent.withSteps(instance.getSteps()); 
        this.validationEnabled = validationEnabled; 
    }

    public SequenceSpecBuilder(SequenceSpec instance) {
        this(instance,true);
    }

    public SequenceSpecBuilder(SequenceSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withChannelTemplate(instance.getChannelTemplate()); 
        this.withReply(instance.getReply()); 
        this.withSteps(instance.getSteps()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.flows.v1.EditableSequenceSpec build() {
        EditableSequenceSpec buildable = new EditableSequenceSpec(fluent.getChannelTemplate(),fluent.getReply(),fluent.getSteps());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SequenceSpecBuilder that = (SequenceSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
